#import "FlutterEasemobPlugin.h"
#import <HyphenateChat/HyphenateChat.h>
#import <EaseIMKit/EaseIMKit.h>
#import <EaseCallKit/EaseCallUIKit.h>
// UI 头文件
#import "EMHeaders.h"
#import "EMDefines.h"

#import "EMChatViewController.h"

@implementation FlutterEasemobPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"flutter_easemob"
            binaryMessenger:[registrar messenger]];
  FlutterEasemobPlugin* instance = [[FlutterEasemobPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }else if ([@"init" isEqualToString:call.method]) {
      [self init:call result:result];
  } else if ([@"login" isEqualToString:call.method]) {
      [self loginUser:call result:result];
  } else if ([@"isLogin" isEqualToString:call.method]) {
      [self checkLogin:result];
  } else if ([@"jumpToPage" isEqualToString:call.method]) {
      [self jumpToChat:call result:result];
  }
}

- (void)init:(FlutterMethodCall *)call result:(FlutterResult)result{
    HDOptions *option = [[HDOptions alloc] init];
    NSDictionary *arguments = call.arguments;
    // appkey替换成自己在环信管理后台注册应用中的appkey
    EMOptions *options = [EMOptions optionsWithAppkey:arguments[@"appKey"]];
    option.tenantId = arguments[@"tenantId"];// 必填项，tenantId获取地址：kefu.easemob.com，“管理员模式 > 设置 > 企业信息”页面的“租户ID”
    // apnsCertName是证书名称，可以先传nil，等后期配置apns推送时在传入证书名称
    options.apnsCertName = nil;
    [[EMClient sharedClient] initializeSDKWithOptions:options];
}

- (void)loginUser:(FlutterMethodCall *)call result:(FlutterResult)result {
    NSDictionary *arguments = call.arguments;
    [[EMClient sharedClient] loginWithUsername:arguments[@"username"] password:arguments[@"password"] completion:^(NSString *aUsername, EMError *aError) {
        if (!aError || aError.code == EMErrorUserAlreadyLoginSame) {
            NSLog(@"IM登录成功");
            result([NSNumber numberWithBool:YES]);
        } else {
            NSLog(@"IM登录失败的原因---%@", aError.errorDescription);
            result([NSNumber numberWithBool:NO]);
        }
    }];
}

- (void)jumpToChat:(FlutterMethodCall *)call result:(FlutterResult)result{
    NSDictionary *arguments = call.arguments;
    // 进入会话页面
    // ConversationId接收消息方的环信ID:@"user2"
    // type聊天类型:EMConversationTypeChat    单聊类型
    EMChatViewController *chatController = [[EMChatViewController alloc]initWithConversationId:arguments[@"imNumber"] conversationType:EMConversationTypeChat];
    UINavigationController *NAV = [[UINavigationController alloc] initWithRootViewController:chatVC];
    UIViewController *rootViewController = [[UIApplication sharedApplication].delegate window].rootViewController;
    NAV.modalPresentationStyle = 0;
    [rootViewController presentViewController:NAV animated:YES completion:nil];

}

- (UIViewController *)visibleViewController {
    UIViewController *rootViewController = [UIApplication sharedApplication].delegate.window.rootViewController;
    return [self getVisibleViewControllerFrom:rootViewController];
}

- (UIViewController *) getVisibleViewControllerFrom:(UIViewController *) vc {
    if ([vc isKindOfClass:[UINavigationController class]]) {
        return [self getVisibleViewControllerFrom:[((UINavigationController *) vc) visibleViewController]];
    } else if ([vc isKindOfClass:[UITabBarController class]]) {
        return [self getVisibleViewControllerFrom:[((UITabBarController *) vc) selectedViewController]];
    } else {
        if (vc.presentedViewController) {
            return [self getVisibleViewControllerFrom:vc.presentedViewController];
        } else {
            return vc;
        }
    }

}

- (UINavigationController *)visibleNavigationController {
    return [[self visibleViewController] navigationController];
}
- (void)checkLogin:(FlutterResult)result{
    if([EMClient sharedClient].isLoggedIn) {
         //已经登录
        result([NSNumber numberWithBool:YES]);
    }else{
        result([NSNumber numberWithBool:NO]);
    }
}

@end
