
import 'dart:async';

import 'package:flutter/services.dart';

class FlutterEasemob {
  // 原生与Flutter 交互渠道
  static const MethodChannel _channel = MethodChannel('flutter_easemob');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  /// 初始化
  /// appKey: “管理员模式 > 渠道管理 > 手机APP”页面的关联的“AppKey”
  /// tenantId: “管理员模式 > 设置 > 企业信息”页面的“租户ID”
  static void init(String appKey, String tenantId) {
    _channel.invokeMethod("init", <String, dynamic>{
      "appKey": appKey,
      "tenantId": tenantId,
    });
  }

  /// 登录
  static Future<bool> login(String username, String password) async {
    return await _channel.invokeMethod("login", <String, dynamic>{
      "username": username,
      "password": password,
    });
  }

  /// 是否登录
  static Future<bool> get isLogin async{
    return await _channel.invokeMethod("isLogin");
  }

  /// 会话页面:
  /// imNumber: “管理员模式 > 渠道管理 > 手机APP”页面的关联的“IM服务号”
  static void jumpToPage(String imNumber) {
    _channel.invokeMethod("jumpToPage", <String, dynamic>{
      "imNumber": imNumber,
    });
  }
}
